/* Copyright (C) 2003 MySQL AB

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA */

#ifndef myx_shared_aux_functions_h
#define myx_shared_aux_functions_h

#include <stdlib.h>
#include <stdio.h>
//#include <glib.h>

#if defined(__WIN__) || defined(_WIN32) || defined(_WIN64)
  #include <winsock2.h>
  #include <windows.h>
#endif

FILE* myx_fopen(const char *filename, const char *mode);

#endif

